R-squared
get_r2.RdCompute R-squared for each variable versus all other covariates
Details
R-squared is a measure of collinearity, defined as how one variable is linearly associated with all other variables in the data set.
Examples
df <- data.frame(X1 = rnorm(100), X2 = rnorm(100), X3 = rnorm(100))
if (FALSE) { # \dontrun{
get_r2(df, rep("numeric", 3))
} # }